package com.jcloud.oss.sdk.sample;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import com.jcloud.jss.Credential;
import com.jcloud.jss.JingdongStorageService;
import com.jcloud.jss.client.ClientConfig;
import com.jcloud.jss.domain.Bucket;
import com.jcloud.jss.domain.acl.AccessControlPolicy;
import com.jcloud.jss.domain.acl.BucketReferer;

/**
 * 这个BucketSample 示范了如何利用京东云提供的Java-SDk进行相关的Bucket操作
 */
public class BucketSample {

    private static String accessKey =  "<yourAccessKey>";
    private static String secreteKey = "<yourSecretKey>";	
    private static String bucketName = "<bucketName>";
    // endpoint以华北为例，其它region请按实际情况填写
    private static String endPoint = "s-bj.jcloud.com";
    
    public static void main(String[] args) throws IOException{
    	/*
    	 * 创建JingdongStorageService实例
    	 */
        Credential credential = new Credential(accessKey, secreteKey);
        ClientConfig config = new ClientConfig();
		JingdongStorageService jss = new JingdongStorageService(credential,config);
		jss.setEndpoint(endPoint);
		
        /*
         * 确认是否这个bucket存在
         */
		if(!jss.hasBucket(bucketName))
		{
			/*
			 * 生成一个新的OSS bucket
			 */
			System.out.println("Creating bucket " + bucketName + "\n");
			jss.createBucket(bucketName);
		}
		
		/*
		 * 列出该账户所有的buckets
		 */
		System.out.println("Listing buckets");
		List<Bucket> buckets = jss.listBucket();
		for (Bucket bucket : buckets) {
			System.out.println("- "+bucket.getName());
		}
		System.out.println();
		
		/*
		 * 设置bucekt的权限 ,只有bucket的权限为public情况下设置的防盗链规则才会生效
		 */
		//设置bucket为private权限
		jss.bucket(bucketName).acl().set();
		
		//设置bucket为public权限
		//jss.bucket(bucketName).acl().internetVisible().allowAnyoneRead().set();
        
        //获取bucket的权限
        AccessControlPolicy policy = jss.bucket(bucketName).acl().get();
        
        //policy.internetVisble是布尔类型：true（Public）；false（Private）
        System.out.println(policy.isInternetVisible());
        if(policy.isInternetVisible() == true) {
        	System.out.println("该bucket的权限为public");
        } else {
        	System.out.println("该bucket的权限为private");
        }
        
		/*
		 * 设置防盗链,只有bucket的权限为public，设置的防盗链规则才会生效
		 */
        BucketReferer bucketReferer = new BucketReferer();
        // 设置白名单
        bucketReferer.setEffect(BucketReferer.Effect.ALLOW);
        //设置黑名单
        //bucketReferer.setEffect(BucketReferer.Effect.DENIED);
        
        // 允许referer为空
        bucketReferer.setAllowNull(true);
        // 添加域名
        List<String> domains = new ArrayList<String>();
    	domains.add("*");
    	domains.add("*.example.com");
    	
    	// 设置域名
    	bucketReferer.setDomains(domains);
    	// 设置防盗链规则
    	jss.bucket(bucketName).setBucketReferer(bucketReferer);
    	
    	//获取白名单(或黑名单)
    	bucketReferer = jss.bucket(bucketName).getBucketReferer();
    	//打印白名单(或黑名单)
    	System.out.println(bucketReferer.toString());
    	
    	//清空白名单(或黑名单)
    	jss.bucket(bucketName).setBucketReferer(new BucketReferer());
    	
    	//获取白名单(或黑名单)
    	bucketReferer = jss.bucket(bucketName).getBucketReferer();
    	//打印白名单(或黑名单)
    	System.out.println(bucketReferer.toString());
    	
		/*
		 * 删除该bucketName的权限
		 */
		jss.bucket(bucketName).acl().delete();
		
		/*
		 * 删除该bucket(需要提前删除该bucket的所有文件或者分片上传碎片,以及该bucekt的访问控制权限)
		 */
		jss.deleteBucket(bucketName);
		
		//关闭OSS客户端
		jss.destroy();
	}
}
