package com.jcloud.oss.sdk.sample;

import java.util.List;

import com.jcloud.jss.Credential;
import com.jcloud.jss.JingdongStorageService;
import com.jcloud.jss.client.ClientConfig;
import com.jcloud.jss.domain.ObjectListing;
import com.jcloud.jss.domain.ObjectSummary;
import com.jcloud.jss.service.BucketService;

public class ListObjectSample {
	
	public static void main(String[] args){	    
		String accessKey =  "<your-AccessKeyId>";
	    String secreteKey = "<your-SecretKey>";		
	    // endpoint以华北为例，其它region请按实际情况填写
	    String endPoint = "s-bj.jcloud.com";
	    String bucketName = "sdk-example";
		//ClientConfig当前为默认配置，用户可根据需要自行配置，如设置连接超时时间等
        ClientConfig config = new ClientConfig();
        
        //构造JingdongStorageService实例
		Credential credential = new Credential(accessKey, secreteKey);
        JingdongStorageService jss = new JingdongStorageService(credential,config);
        //配置endPoint
		jss.setEndpoint(endPoint);
		
		
		//列举出Bucket下所有的Object
		System.out.println("列举出Bucket下所有的Object:");
		//创建BucketService实例
    	BucketService bucketService = jss.bucket(bucketName);
    	//列出bucket下满足条件的文件和文件夹
    	ObjectListing objectList = bucketService.listObject();
    	//列出指定条件下的object名称
        for (ObjectSummary objectSummary : objectList.getObjectSummaries()) {
            System.out.println("objectName : "+objectSummary.getKey());
        }
		
        
		//指定object的最大返回数条数
		System.out.println("\n指定object的最大返回数条数:");
		//创建BucketService实例
		BucketService maxKeysBucketService = jss.bucket(bucketName);
		//指定返回最大条数为10
		maxKeysBucketService.maxKeys(10);
		//列出bucket下满足条件的文件和文件夹
		ObjectListing maxKeysObjectList = maxKeysBucketService.listObject();
		//列出指定条件下的object名称
		for (ObjectSummary objectSummary : maxKeysObjectList.getObjectSummaries()) {
		    System.out.println("objectName : "+objectSummary.getKey());
		}
		
		
		//返回指定前缀的object
		System.out.println("\n返回指定前缀的object:");
		//创建BucketService实例
		BucketService prefixBucketService = jss.bucket(bucketName);
		//指定返回前缀
		prefixBucketService.prefix("jingdong");
		//列出bucket下满足条件的文件和文件夹
		ObjectListing prefixObjectList = prefixBucketService.listObject();
		//列出指定条件下的object名称
		for (ObjectSummary objectSummary : prefixObjectList.getObjectSummaries()) {
		    System.out.println("objectName : "+objectSummary.getKey());
		}
		
		
		//从指定Object后返回
		System.out.println("\n从指定Object后返回:");
		//创建BucketService实例
		BucketService markerBucketService = jss.bucket(bucketName);
		//返回"file"后以字典序排序的Object信息，结果中不包含"file"
		markerBucketService.marker("file");
		//列出bucket下满足条件的文件和文件夹
		ObjectListing markerObjectList = markerBucketService.listObject();
		//列出指定条件下的object名称
		for (ObjectSummary objectSummary : markerObjectList.getObjectSummaries()) {
		    System.out.println("objectName : "+objectSummary.getKey());
		}
		
		
		//分页获取所有Object，每页maxKeys条Object
		System.out.println("\n分页获取所有Object:");
		String pageMarker = null;
		ObjectListing pageObjectList = null;
		do {
			System.out.println(".................page....................");
			//创建BucketService实例
			BucketService pageService = jss.bucket(bucketName);
			//返回marker后以字典序排序的Object信息，结果中不包含marker
			pageService.marker(pageMarker);
			//指定返回最大条数为5
			pageService.maxKeys(5);
			//列出bucket下满足条件的文件和文件夹
			pageObjectList = pageService.listObject();
			//列出指定条件下的object名称
			List<ObjectSummary> objectSummaries = pageObjectList.getObjectSummaries();
			for (ObjectSummary objectSummary : objectSummaries) {
			    System.out.println("objectName : "+objectSummary.getKey());
			}
			pageMarker = objectSummaries.get(objectSummaries.size()-1).getKey();
		} while (pageObjectList.isHasNext());
		

		//分页获取所有特定Object后的Object
		System.out.println("\n分页获取所有特定Object后的Object:");
		//分页获取"file"后以字典序排序的Object信息，结果中不包含"file"
		String pageMarker2 = "file";
		ObjectListing pageMarkerObjectList = null;
		do {
			System.out.println(".................page....................");
			//创建BucketService实例
			BucketService pageMarkerBucketService = jss.bucket(bucketName);
			//返回marker后以字典序排序的Object信息，结果中不包含marker
			pageMarkerBucketService.marker(pageMarker2);
			//指定返回最大条数为5
			pageMarkerBucketService.maxKeys(5);
			//列出bucket下满足条件的文件和文件夹
			pageMarkerObjectList = pageMarkerBucketService.listObject();
			//列出指定条件下的object名称
			List<ObjectSummary> objectSummaries = pageMarkerObjectList.getObjectSummaries();
			for (ObjectSummary objectSummary : objectSummaries) {
			    System.out.println("objectName : "+objectSummary.getKey());
			}
			pageMarker2 = objectSummaries.get(objectSummaries.size()-1).getKey();
		} while (pageMarkerObjectList.isHasNext());
		
		
		//分页所有获取指定前缀的Object
		System.out.println("\n分页所有获取指定前缀的Object:");
		String pageMarker3 = null;
		ObjectListing pagePrefixObjectList = null;
		do {
			System.out.println(".................page....................");
			//创建BucketService实例
			BucketService pagePrefixBucketService = jss.bucket(bucketName);
			//指定返回前缀的object
			pagePrefixBucketService.prefix("file");
			//返回marker后以字典序排序的Object信息，结果中不包含marker
			pagePrefixBucketService.marker(pageMarker3);
			//指定返回最大条数为5
			pagePrefixBucketService.maxKeys(5);
			//列出bucket下满足条件的文件和文件夹
			pagePrefixObjectList = pagePrefixBucketService.listObject();
			//列出指定条件下的object名称
			List<ObjectSummary> objectSummaries = pagePrefixObjectList.getObjectSummaries();
			for (ObjectSummary objectSummary : objectSummaries) {
			    System.out.println("objectName : "+objectSummary.getKey());
			}
			pageMarker3 = objectSummaries.get(objectSummaries.size()-1).getKey();
		} while (pagePrefixObjectList.isHasNext());

		
		//我们可以通过设置 Prefix 参数来获取某个目录下所有的文件
		System.out.println("\n递归列出目录下所有文件:");
		//创建BucketService实例
		BucketService dirBucketService = jss.bucket(bucketName);
		//获取"jingdong/"下所有的文件
		dirBucketService.prefix("jingdong/");
		//列出bucket下满足条件的文件和文件夹
		ObjectListing dirObjectList = dirBucketService.listObject();
		//列出指定条件下的object名称
		System.out.println("objectName : ");
		for (ObjectSummary objectSummary : dirObjectList.getObjectSummaries()) {
		    System.out.println(objectSummary.getKey());
		}
		//累出指定条件下的文件夹
		System.out.println("\nCommonPrefixes : ");
		for (String commonPrefixes : dirObjectList.getCommonPrefixes()) {
		    System.out.println(commonPrefixes);
		}
		
		
		//列出目录下的文件和子目录
		System.out.println("\n列出目录下的文件和子目录:");
		//创建BucketService实例
		BucketService dirAndFileService = jss.bucket(bucketName);
		//列出"jingdong/"下的文件和子目录,需要注意的是delimier需要与hasCommonPrefix配合使用才生效
		dirAndFileService.prefix("jingdong/").delimiter("/").hasCommonPrefix(true);
		//列出bucket下满足条件的文件和文件夹
		ObjectListing dirAndFileObjectList = dirAndFileService.listObject();
		//列出指定条件下的object名称
		System.out.println("objectName : ");
		for (ObjectSummary objectSummary : dirAndFileObjectList.getObjectSummaries()) {
		    System.out.println(objectSummary.getKey());
		}
		//累出指定条件下的文件夹
		System.out.println("\nCommonPrefixes : ");
		for (String commonPrefixes : dirAndFileObjectList.getCommonPrefixes()) {
		    System.out.println(commonPrefixes);
		}
        
		
		//JingdongStorageService对象内部维护一组HTTP连接池，在不使用该对象之前需要调用其destroy方法关闭连接池，
		//请注意，一旦调用destroy方法，该对象就不能再次被使用，否则将会抛出异常。
		jss.destroy();
	}

}
