package com.jcloud.oss.sdk.sample;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import com.jcloud.jss.Credential;
import com.jcloud.jss.JingdongStorageService;
import com.jcloud.jss.client.ClientConfig;
import com.jcloud.jss.domain.multipartupload.InitMultipartUploadResult;
import com.jcloud.jss.domain.multipartupload.ListPartsResult;
import com.jcloud.jss.domain.multipartupload.MultipartUploadListing;
import com.jcloud.jss.domain.multipartupload.Part;
import com.jcloud.jss.domain.multipartupload.Upload;
import com.jcloud.jss.domain.multipartupload.UploadPartResult;
import com.jcloud.jss.service.BucketService;

public class MultipartUploadSample {
	//-------------------------------测试用的--------------------------------------------------------------
  private static String accessKey =  "<your-AccessKeyId>";
  private static String secreteKey = "<your-SecretKey>";
  private static String endPoint = "s-bj.jcloud.com";
  private static File file = new File("D:\\tmp\\sign.txt");
  private static String bucketName = "jss-test";
  private static String key = "sign.txt";
  //---------------------------------------------------------------------------------------------

    
    public static void main(String[] args) throws IOException{
    	
    	/*
    	 * 创建JingdongStorageService实例
    	 */
        Credential credential = new Credential(accessKey, secreteKey);
        ClientConfig config = new ClientConfig();
        
		JingdongStorageService jss = new JingdongStorageService(credential,config);
		jss.setEndpoint(endPoint);
        /*
         * 确认是否这个bucket存在
         */
		if(!jss.hasBucket(bucketName))
		{
			/*
			 * 生成一个新的OSS bucket
			 */
			System.out.println("Creating bucket " + bucketName + "\n");
			jss.createBucket(bucketName);
		}

		//使用低冗余存储，则使用该句代码
		//jss.bucket(bucketName).object(key).getBuilder().getHeaders().put(JssHeaders.X_JSS_STORAGE_CLASS, StorageClass.ReducedRedundancy.toString());
		
		/*
		 * 初始化一个分片上传任务,服务器将会返回该分片上传任务的UploadId
		 */
		System.out.println("初始化一个分片上传任务");
		InitMultipartUploadResult initResult = jss.bucket(bucketName).object(key).initMultipartUpload();
		System.out.println("uploadId: " + initResult.getUploadId() + "\n" + 
						   "bucketName: " + initResult.getBucket() + "\n" + 
						   "key: "+initResult.getKey());
		System.out.println();
		/*
		 * uploadPartResults 用于记录每一个上传的分片的信息，在完成分片上传的步骤中会用到
		 */
		List<UploadPartResult> uploadPartResults = new ArrayList<UploadPartResult>();
		
		/*
		 * 上传分片
		 */
		//----------------------第一片----------------------------------------
		long partSize = 100;
		int partNum = 1;
		InputStream inputStream = new FileInputStream(file);
		UploadPartResult result = jss.bucket(bucketName)
				.object(key).entity(partSize, inputStream)
				.uploadPart(initResult.getUploadId(), partNum);
		
		uploadPartResults.add(result);
		
		System.out.println("第一个分片" 		 + "\n" +
						   "eTag: " 		 + result.geteTag() + "\n" +
						   "PartNumber: "    + result.getPartNumber());
		System.out.println();
		//----------------------第二片----------------------------------------
		partSize = file.length() - partSize*1;
		partNum = 2;
		//如果不是连续传输分片，则需要利用下面代码，将inputStream的开始位置移动到本次传输开始的位置
		//int fileOffset = 5;
		//ByteStreams.skipFully(inputStream, fileOffset);
		result = jss.bucket(bucketName)
				.object(key).entity(partSize, inputStream)
				.uploadPart(initResult.getUploadId(), partNum);
		uploadPartResults.add(result);
		System.out.println("第二个分片" 		 + "\n" +
						   "eTag: " 		 + result.geteTag() + "\n" +
				   		   "PartNumber: "    + result.getPartNumber());
		System.out.println();
		/*
		 * 获取指定Upload ID所有已上传的分片
		 */
		System.out.println("获取指定Upload ID所有已上传的分片");
	    ListPartsResult partList = jss.bucket(bucketName).object(key).listParts(initResult.getUploadId());
		for(Part part : partList.getParts()) {
			System.out.println("PartNumber:"   + part.getPartNumber() + "\n" +
							   "Size:" 		   + part.getSize()		  + "\n" +
							   "ETag:" 		   + part.geteTag()       + "\n" +
							   "LastModified:" + part.getLastModified());
			System.out.println();
		}	
		/*
		 * 获取bucket空间内所有分片上传事件
		 */
		System.out.println("获取bucket空间内所有分片上传事件");
		BucketService bucketService = jss.bucket(bucketName);
		//增加前缀匹配
		//bucketService.prefix("<your perfix>");
		
		MultipartUploadListing multipartUploadListing = bucketService.listMultipartUploads();
		for (Upload upload : multipartUploadListing.getUploads()) {
			System.out.println("UploadId:"   + upload.getUploadId() + "\n" +
							   "Key:" 		 + upload.getKey()	    + "\n" +
							   "Initiated:"  + upload.getInitiated());
			System.out.println();
	    }
		
		/*
		 * 完成分片上传 
		 */
		Collections.sort(uploadPartResults,new Comparator<UploadPartResult>() {
			@Override
			public int compare(UploadPartResult p1,UploadPartResult p2) {
				return p1.getPartNumber() - p2.getPartNumber();
			}
		});
		String eTag = jss.bucket(bucketName).object(key).completeMultipartUpload(initResult.getUploadId(), uploadPartResults);
		System.out.println("完成分片上传 " + "\n" + 
				 		   "ETag: " + eTag);
		
		/*
		 * 取消该分片上传任务，已经上传的分片会自动删除
		 */
		//jss.bucket(bucketName).object(key).abortMultipartUpload(initResult.getUploadId());
		
		//关闭OSS客户端
		jss.destroy();
	}

}
