package com.jcloud.oss.sdk.sample;

import java.io.File;
import java.io.IOException;

import com.jcloud.jss.Credential;
import com.jcloud.jss.JingdongStorageService;
import com.jcloud.jss.client.ClientConfig;
import com.jcloud.jss.domain.ObjectListing;
import com.jcloud.jss.domain.ObjectSummary;
import com.jcloud.jss.domain.StorageObject;
import com.jcloud.jss.domain.result.MoveObjectResult;
import com.jcloud.jss.service.BucketService;
import com.jcloud.jss.service.ObjectService;

/**
 * 用于object相关的基本功能演示，如上传文件，下载文件，删除文件，列举指定bucket下的object等<br>
 * 仅演示最基础的用法，其他扩展用法以及功能请参考各模块详细代码示例
 */
public class ObjectSample {
	
	public static void main(String[] args) throws IOException{
		//您的AccessKey和SecretKey可以登陆到京东云存储的控制台，在【Access Key 管理】中查看。
	    String accessKey =  "<your-AccessKeyId>";
	    String secreteKey = "<your-SecretKey>";		
	    // endpoint以华北为例，其它region请按实际情况填写
	    String endPoint = "s-bj.jcloud.com";
	    File file = new File("D:/index.html"); 
	    String bucketName = "sdk-example";
	    String objectName = "index.html";
	    String sourceBucketName = "sdk-example";//moveObject的源bucket
	    String sourceKey = "index.html";//moveObject的源object key	 
	    String destinationBucketName = "sdk-example";//moveObject的目的bucket
	    String destinationKey = "dest_index.html";//moveObject的目的object key
		//ClientConfig当前为默认配置，用户可根据需要自行配置，如设置连接超时时间等
        ClientConfig config = new ClientConfig();
        
        //构造JingdongStorageService实例
		Credential credential = new Credential(accessKey, secreteKey);
        JingdongStorageService jss = new JingdongStorageService(credential,config);
        //配置endPoint
		jss.setEndpoint(endPoint);
		
		//上传文件
		System.out.println("上传文件 : ");
		//创建objectService实例
		ObjectService PutObjectService = jss.bucket(bucketName).object(objectName);
		//设置上传文件Content-type为"text/html"。函数返回上传数据的Etag,目前Etag的值为上传数据的MD5
        String fileMd5 = PutObjectService.entity(file).contentType("text/html").put();
		System.out.println("putObject \t MD5 = "+fileMd5);	
		
		
		//下载文件
		System.out.println("\n下载文件 : ");
		//创建objectService实例
		ObjectService getObjectService = jss.bucket(bucketName).object(objectName);
		//获取object对象
		StorageObject storageObject = getObjectService.get();
		//将文件下载到本地文件中，如下示例是将指定的object下载到"D:/down.html"中
		storageObject.toFile(new File("D:/down.html"));
		System.out.println("下载完毕！");
		
		
		//移动文件
		System.out.println("\n移动文件 : ");
		//创建objectService实例
		ObjectService MoveObjectService = jss.bucket(destinationBucketName).object(destinationKey);
		//将sourceBucket下的sourceObject移动到destinationBucket下的destinationObject,返回移动后object的etag和lastModified
		MoveObjectResult moveObjectResult = MoveObjectService.moveFrom(sourceBucketName, sourceKey).move();
		System.out.println("LastModified : "+moveObjectResult.getLastModified());
		System.out.println("Etag : "+moveObjectResult.getEtag());
		
		
		//列出bucket下object
		System.out.println("\n列出bucket下object : ");
		//创建BucketService实例
    	BucketService listObjectService = jss.bucket(bucketName);
    	//列出bucket下满足条件的文件和文件夹
    	ObjectListing objectList = listObjectService.listObject();
    	//列出指定条件下的object名称
        for (ObjectSummary objectSummary : objectList.getObjectSummaries()) {
            System.out.println("objectName : "+objectSummary.getKey());
        }
		
        
        //删除文件
        System.out.println("删除文件：");
		//创建objectService实例
		ObjectService deleteObjectService = jss.bucket(destinationBucketName).object(destinationKey);
		//删除object
		deleteObjectService.delete();
        System.out.println("删除完毕！");
        
		
		//JingdongStorageService对象内部维护一组HTTP连接池，在不使用该对象之前需要调用其destroy方法关闭连接池，
		//请注意，一旦调用destroy方法，该对象就不能再次被使用，否则将会抛出异常。
		jss.destroy();
	}
}
